pub struct Inlinee<'a>(/* private fields */);Expand description
An inlined function that can evaluate to line information.
Implementations
Sourceimpl<'a> Inlinee<'a>
impl<'a> Inlinee<'a>
Sourcepub fn lines(
&self,
parent_offset: PdbInternalSectionOffset,
inline_site: &InlineSiteSymbol<'a>,
) -> InlineeLineIterator<'a>
pub fn lines( &self, parent_offset: PdbInternalSectionOffset, inline_site: &InlineSiteSymbol<'a>, ) -> InlineeLineIterator<'a>
Returns an iterator over line records for an inline site.
Note that line records are not guaranteed to be ordered by source code offset. If a
monotonic order by PdbInternalSectionOffset or Rva is required, the lines have to be
sorted manually.