Local

Struct Local 

pub struct Local<I: ItemIndex>(pub I);
An ItemIndex that is local to a module.

This index is usually part of a CrossModuleRef. It cannot be used to query the TypeInformation or IdInformation streams directly. Instead, it must be looked up in the CrossModuleImports of the module it belongs to in order to obtain the global index.

See ItemIndex::is_cross_module for more information.

Tuple Fields

0: I