SeparatedCodeSymbol

Struct SeparatedCodeSymbol 

pub struct SeparatedCodeSymbol {
    pub parent: SymbolIndex,
    pub end: SymbolIndex,
    pub len: u32,
    pub flags: SeparatedCodeFlags,
    pub offset: PdbInternalSectionOffset,
    pub parent_offset: PdbInternalSectionOffset,
}
A separated code symbol.

Symbol kind S_SEPCODE.

Fields

parent: SymbolIndex

The parent scope that this block is nested in.

end: SymbolIndex

The end symbol of this block.

len: u32

The length of the block.

flags: SeparatedCodeFlags

Flags for this symbol

offset: PdbInternalSectionOffset

Code offset of the start of the separated code.

parent_offset: PdbInternalSectionOffset

Parent offset.