pub struct TypeProperties(/* private fields */);Implementations
Sourceimpl TypeProperties
impl TypeProperties
Sourcepub fn constructors(self) -> bool
pub fn constructors(self) -> bool
Indicates if a type has constructors or destructors.
Sourcepub fn overloaded_operators(self) -> bool
pub fn overloaded_operators(self) -> bool
Indicates if a type has any overloaded operators.
Sourcepub fn is_nested_type(self) -> bool
pub fn is_nested_type(self) -> bool
Indicates if a type is a nested type, e.g. a union defined inside a class.
Sourcepub fn contains_nested_types(self) -> bool
pub fn contains_nested_types(self) -> bool
Indicates if a type contains nested types.
Sourcepub fn overloaded_assignment(self) -> bool
pub fn overloaded_assignment(self) -> bool
Indicates if a class has overloaded the assignment operator.
pub fn overloaded_casting(self) -> bool
Sourcepub fn forward_reference(self) -> bool
pub fn forward_reference(self) -> bool
Indicates if a type is a forward reference, i.e. an incomplete Type that serves as a placeholder until a complete Type can be built. This is necessary for e.g. self-referential data structures, but other more common declaration/definition idioms can cause forward references too.
pub fn scoped_definition(self) -> bool
pub fn has_unique_name(self) -> bool
pub fn sealed(self) -> bool
pub fn hfa(self) -> u8
pub fn intrinsic_type(self) -> bool
pub fn mocom(self) -> u8